@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QDir>
 #include <QFile>
@@ -63,7 +48,7 @@ void FeedList::loadFeeds(FilterList *filter_list, SyndicationActivity *activity)
             idir.append(DirSeparator());
 
         Out(SYS_GEN | LOG_NOTICE) << "Loading feed from directory " << idir << endl;
-        Feed *feed = 0;
+        Feed *feed = nullptr;
         try {
             feed = new Feed(idir);
             connect(feed, &Feed::downloadLink, activity, &SyndicationActivity::downloadLink);
@@ -202,7 +187,7 @@ Qt::ItemFlags FeedList::flags(const QModelIndex &index) const
 Feed *FeedList::feedForIndex(const QModelIndex &idx)
 {
     if (!idx.isValid())
-        return 0;
+        return nullptr;
 
     return feeds.at(idx.row());
 }
@@ -213,7 +198,7 @@ Feed *FeedList::feedForDirectory(const QString &dir)
         if (f->directory() == dir)
             return f;
 
-    return 0;
+    return nullptr;
 }
 
 bool FeedList::removeRows(int row, int count, const QModelIndex &parent)
